@@ -6,10 +6,10 @@
 struct _DestReceiver;
 
 extern void ExecKillStmt(KillStmt *stmt);
-extern void ExecShowSchemas(struct _DestReceiver *dest);
-extern void ExecShowDatabases(struct _DestReceiver *dest);
-extern void ExecShowTables(char *schema, struct _DestReceiver *dest);
-extern void ExecShowCreateTable(RangeVar *var, struct _DestReceiver *dest);
+extern void ExecShowSchemas(char *pattern, struct _DestReceiver *dest);
+extern void ExecShowDatabases(char *pattern, struct _DestReceiver *dest);
+extern void ExecShowTables(char *pattern, char *schema, struct _DestReceiver *dest);
+extern void ExecShowCreateTable(ShowCreateTableStmt *stmt, struct _DestReceiver *dest);
 extern void ExecShowProcessList(bool local, struct _DestReceiver *dest);
 extern void ExecSendShardStmt(char *shard, char *query, struct _DestReceiver *dest);
 extern void ExecSendShardStmtInternal(Oid shardid, const char *query, struct _DestReceiver *dest);
