@@ -433,6 +433,8 @@ typedef enum NodeTag
 	T_SendShardStmt,
 	T_FetchMySQLVarStmt,
 	T_MySQLVarRef,
+	T_ShowCollationStmt,
+	T_MultiVariableSetStmt,
 
 	/*
 	 * TAGS FOR PARSE TREE NODES (parsenodes.h)
