@@ -27,7 +27,6 @@
  * ----------------------------------------------------------------
  */
 
-struct Remote_OLD_state;
 /* ----------------
  *		PlannedStmt node
  *
@@ -276,6 +275,9 @@ typedef struct Append
 
 	/* Info for run-time subplan pruning; NULL if we're not doing that */
 	struct PartitionPruneInfo *part_prune_info;
+
+	/* Create a worker for each child, and keep result order of it */
+	bool  keep_order;
 } Append;
 
 /* ----------------
@@ -849,6 +851,33 @@ typedef struct RemoteJoin
 	Oid			rj_shardid;
 } RemoteJoin;
 
+typedef struct RemtePlan
+{
+	Plan plan;
+	/* The target shard */
+	Oid shard;
+	/* The base relation id if it is a table scan */
+	Index baserelid;
+	/* The geneated prepared sql*/
+	const char *prepared_sql;
+
+	/* Fields needed by update/delete to construct the update/delete query */
+	List *topwhere;
+	List *sortexpr;
+	List *sortop;
+	List *sortnullfirst;
+	Node *limitoff;
+	Node *limitcnt;
+
+	/* The parameters refered in prepared_sql*/
+	List *params;
+	List *param_locations;
+	/* The target list of the prepared_sql */
+	List *scan_list;
+
+	/* The orignal target list, saved for explain */
+	List *original_target_list;
+} RemotePlan;
 /* ----------------
  *		hash join node
  * ----------------
@@ -866,11 +895,6 @@ typedef struct HashJoin
 typedef struct Material
 {
 	Plan		plan;
-
-	/*
-  	  dzw: fetch all rows at once in ExecInitMaterial()/rescan for remote table.
-	*/
-	bool		remote_fetch_all;
 } Material;
 
 /* ----------------
@@ -930,40 +954,6 @@ typedef struct Agg
 	List	   *chain;			/* chained Agg/Sort nodes */
 } Agg;
 
-struct AggColMeta;
-
-typedef struct MergeRemoteAgg
-{
-	Plan		plan;
-	int			numGroupingCols;		/* number of grouping columns */
-
-	Index *groupingCols;		/* the i'th slot is the i'th ORDER BY/GROUP BY item's
-	TargetEntry::ressortgroupref in the targetlist of the RS/RJ children nodes.
-	*/
-
-	Bitmapset  *aggParams;		/* IDs of Params used in Aggref inputs */
-	/* Note: planner provides numGroups & aggParams only in HASHED/MIXED case */
-	List	   *groupingSets;	/* grouping sets to use */
-	List	*remote_plans;		/* list of RS/RJ children nodes, which provide
-	partial agg results for this node to merge to form final results. */
-
-	bool all_group_vars; // See RemoteAggPath::all_group_vars.
-	/*
-	  grouping column(grouping clause) operators.
-	*/
-	Oid			*sortLTOperators;
-	Oid			*sortEQOperators;
-	/*
-	  Non-AVG aggregation column numbers(starting from 1) of input relation.
-	  AVG columns are stored in remote_aggrefs.
-	*/
-	struct AggColMeta *agg_cols;
-	int agg_cols_end;
-
-	List *aggs_need_rewrite;
-	List *aggs_rewrited;
-} MergeRemoteAgg;
-
 /* ----------------
  *		window aggregate node
  * ----------------
