@@ -15,6 +15,9 @@
 #ifndef REMOTE_PATH_H
 #define REMOTE_PATH_H
 
+#define IS_REMOTE_RELOPT(root, rel) \
+	((rel)->relshardid && rt_fetch((rel)->relid, (root)->parse->rtable)->relkind == RELKIND_RELATION)
+
 extern Path *create_remotescan_path(PlannerInfo *root, RelOptInfo *rel,
 				    Relids required_outer, bool parallel_safe);
 extern RemotePath *
