@@ -77,15 +77,24 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
     elif row[0] == 'rbr':
         meta_ha_mode = 2
 
+    meta_cursor.execute("select id, hostaddr from server_nodes where machine_type='computer'")
+    server_rows = meta_cursor.fetchall()
+    idmap = {}
+    for server_row in server_rows:
+        idmap[bytes(server_row[1])] = server_row[0]
+
     meta_cursor0 = meta_conn.cursor(buffered=True, dictionary=True)
 
     # insert computing nodes info into meta-tables.
-    stmt = "insert into comp_nodes(id, name, hostaddr, port, db_cluster_id,user_name,passwd, svr_node_id) values(%s, %s, %s, %s, %s, %s, %s, 1)"
+    stmt = "insert into comp_nodes(id, name, hostaddr, port, db_cluster_id,user_name,passwd, svr_node_id) values(%s, %s, %s, %s, %s, %s, %s, %s)"
     idstmt = "insert into comp_nodes_id_seq(id) values(%s)"
     meta_cursor0.execute("start transaction")
 
     for compcfg in jscfg:
-        meta_cursor.execute(stmt, (compcfg['id'], compcfg['name'],compcfg['ip'], compcfg['port'], cluster_id, compcfg['user'], compcfg['password']))
+        svr_node_id = 1
+        if compcfg['ip'] in idmap:
+            svr_node_id = idmap[compcfg['ip']]
+        meta_cursor.execute(stmt, (compcfg['id'], compcfg['name'],compcfg['ip'], compcfg['port'], cluster_id, compcfg['user'], compcfg['password'], svr_node_id))
         if intoSeqTable:
             meta_cursor.execute(idstmt % str(compcfg['id']))
     meta_cursor.close()
