@@ -48,10 +48,16 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
     row = meta_cursor.fetchone()
     cluster_id = row[0]
 
+    meta_cursor.execute("select id, hostaddr from server_nodes where machine_type='storage'")
+    server_rows = meta_cursor.fetchall()
+    idmap = {}
+    for server_row in server_rows:
+        idmap[bytes(server_row[1])] = server_row[0]
+
     num_nodes = 0
 
     add_shard_stmt = "insert into shards(name, when_created, num_nodes, db_cluster_id) values(%s, now(), 0, %s)"
-    add_shard_node_stmt = "insert into shard_nodes(hostaddr, port, user_name, passwd, shard_id, db_cluster_id, svr_node_id, master_priority) values(%s, %s, %s, %s, %s, %s, 1,0)"
+    add_shard_node_stmt = "insert into shard_nodes(hostaddr, port, user_name, passwd, shard_id, db_cluster_id, svr_node_id, master_priority) values(%s, %s, %s, %s, %s, %s, %s,0)"
 
     jscfg = []
     nshards = 0
@@ -92,7 +98,10 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
         shardcfg['shard_id'] = shard_id
         num_nodes = 0
         for val in shardcfg['shard_nodes']:
-            meta_cursor.execute(add_shard_node_stmt, (val['ip'], val['port'], val['user'], val['password'], shard_id, cluster_id))
+            svr_node_id = 1
+            if val['ip'] in idmap:
+                svr_node_id = idmap[val['ip']]
+            meta_cursor.execute(add_shard_node_stmt, (val['ip'], val['port'], val['user'], val['password'], shard_id, cluster_id, svr_node_id))
             meta_cursor0.execute("select last_insert_id() as id")
             row0 = meta_cursor0.fetchone()
             val['shard_node_id'] = row0['id']
