@@ -37,14 +37,14 @@ meta_cursor = meta_conn.cursor(prepared=True)
 meta_cursor0 = meta_conn.cursor()
 
 # insert cluster info into db_clusters
-stmt = "insert into db_clusters(name, nick_name, owner, ddl_log_tblname, business, ha_mode) values(%s, %s, %s, %s, %s, %s)"
+stmt = "insert into db_clusters(name, nick_name, owner, ddl_log_tblname, business, memo, ha_mode) values(%s, %s, %s, %s, %s, %s, %s)"
 ddl_log_tblname='ddl_ops_log_'+args.cluster_name  # must be like this, don't change the format
 
 print "Creating database cluster " + args.cluster_name
 print "Step 1. Inserting meta-data row for database cluster " + args.cluster_name
 meta_cursor0.execute("start transaction")
 
-meta_cursor.execute(stmt, (args.cluster_name, args.cluster_biz, args.cluster_owner, ddl_log_tblname, args.cluster_biz, args.ha_mode))
+meta_cursor.execute(stmt, (args.cluster_name, args.cluster_biz, args.cluster_owner, ddl_log_tblname, args.cluster_biz, args.cluster_biz, args.ha_mode))
 
 meta_cursor0.execute("commit")
 
