@@ -91,6 +91,12 @@ def install_pg(config_template_file, install_path, compcfg, valgrind):
     psql_cmd = cmd0 + install_path + "/bin/psql -h localhost -p" + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
     os.system(psql_cmd)
 
+	# add mysql functions for mysql clients.
+    psql_cmd2 =cmd0 +  install_path + "/bin/psql -h localhost -p" + str(compcfg['port']) + " -U " + getpass.getuser() + " -d template1 -f " + install_path + "/scripts/mysql_funcs.sql"
+    os.system(psql_cmd2)
+    psql_cmd2 = cmd0 + install_path + "/bin/psql -h localhost -p" + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -f " + install_path + "/scripts/mysql_funcs.sql"
+    os.system(psql_cmd2)
+
     # append the new instance's port to datadir mapping into instance_list.txt
     if not os.path.exists(etc_path):
         os.mkdir(etc_path)
