@@ -32,17 +32,18 @@ use Kunlun_Metadata_DB;
 --
 -- Table structure for table `commit_log`
 --
-
 DROP TABLE IF EXISTS `commit_log_template_table`;
 /*!40101 SET @saved_cs_client     = @@character_set_client */;
  SET character_set_client = utf8mb4 ;
 CREATE TABLE `commit_log_template_table` (
+  `id` int unsigned NOT NULL AUTO_INCREMENT,
   `comp_node_id` int unsigned NOT NULL, -- no FK for perf
   `txn_id` bigint unsigned NOT NULL,
   `next_txn_cmd` enum('commit','abort') NOT NULL,
   `prepare_ts` timestamp(6) default current_timestamp(6),
   `written_shards` json NOT NULL,
-  PRIMARY KEY (`txn_id`,`comp_node_id`)
+  PRIMARY KEY (`id`,`comp_node_id`,`txn_id`),
+  UNIQUE KEY `commit_log_unik` (`comp_node_id`,`txn_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8
 /*!50100 PARTITION BY LIST (`comp_node_id`)
 SUBPARTITION BY HASH (((`txn_id` >> 32) DIV 86400))
@@ -243,6 +244,8 @@ CREATE TABLE `server_nodes` (
   `extra_props` text,
   `node_stats` enum('running','idle','dead') DEFAULT 'running',
   `nodemgr_tcp_port` int DEFAULT NULL,
+  `nodemgr_prometheus_port` int DEFAULT NULL,
+  `current_port_pos` int DEFAULT NULL,
   `machine_type` enum('storage','computer') DEFAULT NULL,
   `port_range` varchar(256) DEFAULT NULL,
   `used_port` text,
@@ -542,11 +545,7 @@ create table table_move_jobs (
 	when_ended timestamp(6) NULL default null,
 	status enum('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed') not null default 'not_started',
 	-- extra info for expanding 
-	memo text default null,
- 	FOREIGN KEY (src_shard)  references shards(id),
- 	FOREIGN KEY (src_shard_node) references shard_nodes(id),
- 	FOREIGN KEY (dest_shard)  references shards(id),
- 	FOREIGN KEY (dest_shard_node) references shard_nodes(id)
+	memo text default null
 ) ENGINE=InnoDB DEFAULT charset=utf8;
 
 -- Rbr failover table
@@ -583,6 +582,7 @@ CREATE TABLE `cluster_mgr_nodes` (
 	`id` int unsigned NOT NULL AUTO_INCREMENT,
 	`hostaddr` varchar(8192) character set latin1 NOT NULL,
 	`port` int unsigned DEFAULT NULL,
+	`prometheus_port` int unsigned DEFAULT NULL,
 	`member_state` enum('source','replica') DEFAULT 'replica',
 	PRIMARY KEY (`id`)
 ) ENGINE=InnoDB DEFAULT charset=utf8;
